@@ -167,7 +167,7 @@ class Lens(Graph):
         pcurie = "%s:%s" % (ns, local)
 
         if isinstance(value, Literal):
-            p = ET.Element("span")
+            p = ET.Element("div")
             p.set("rel", pcurie)
             if value.language:
                 sp = ET.Element("span")
@@ -438,10 +438,12 @@ class Render(Command):
             doc += ET.tostring(child, encoding="utf-8")
         doc += '</html>'
 
-        from xml.dom import minidom
-        from StringIO import StringIO
-        doc = minidom.parse(StringIO(doc))
-        print doc.toprettyxml()
+        print doc
+
+#        from xml.dom import minidom
+#        from StringIO import StringIO
+#        doc = minidom.parse(StringIO(doc))
+#        print doc.toprettyxml()
 
 def render():
     Render().command()
